Welcome to mirror list, hosted at ThFree Co, Russian Federation.

git.blender.org/blender.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
Diffstat (limited to 'source/blender/editors/gizmo_library/gizmo_geometry.h')
-rw-r--r--source/blender/editors/gizmo_library/gizmo_geometry.h22
1 files changed, 11 insertions, 11 deletions
diff --git a/source/blender/editors/gizmo_library/gizmo_geometry.h b/source/blender/editors/gizmo_library/gizmo_geometry.h
index de976bbad48..254fb6b0957 100644
--- a/source/blender/editors/gizmo_library/gizmo_geometry.h
+++ b/source/blender/editors/gizmo_library/gizmo_geometry.h
@@ -24,31 +24,31 @@
/** \file gizmo_geometry.h
* \ingroup wm
*
- * \name Manipulator Geometry
+ * \name Gizmo Geometry
*
* \brief Prototypes for arrays defining the manipulator geometry. The actual definitions can be found in files usually
* called geom_xxx_manipulator.c
*/
#ifndef __GIZMO_GEOMETRY_H__
#define __GIZMO_GEOMETRY_H__
-typedef struct ManipulatorGeomInfo {
+typedef struct GizmoGeomInfo {
int nverts;
int ntris;
const float (*verts)[3];
const float (*normals)[3];
const unsigned short *indices;
-} ManipulatorGeomInfo;
+} GizmoGeomInfo;
-/* arrow manipulator */
-extern ManipulatorGeomInfo wm_manipulator_geom_data_arrow;
+/* arrow gizmo */
+extern GizmoGeomInfo wm_gizmo_geom_data_arrow;
-/* cube manipulator */
-extern ManipulatorGeomInfo wm_manipulator_geom_data_cube;
+/* cube gizmo */
+extern GizmoGeomInfo wm_gizmo_geom_data_cube;
-/* dial manipulator */
-extern ManipulatorGeomInfo wm_manipulator_geom_data_dial;
+/* dial gizmo */
+extern GizmoGeomInfo wm_gizmo_geom_data_dial;
#endif /* __GIZMO_GEOMETRY_H__ */
@@ -24,31 +24,31 @@
*
- * \brief Prototypes for arrays defining the manipulator geometry. The actual definitions can be found in files usually
- * called geom_xxx_manipulator.c
+ * \brief Prototypes for arrays defining the gizmo geometry. The actual definitions can be found in files usually
+ * called geom_xxx_gizmo.c
*/
#ifndef __GIZMO_GEOMETRY_H__